@@ -3,7 +3,7 @@ import argparse
 import apache_beam as beam
 from apache_beam.io import ReadFromText
 from apache_beam.io import WriteToAvro
-from apache_beam.options.pipeline_options import PipelineOptions, SetupOptions
+from apache_beam.options.pipeline_options import PipelineOptions
 
 from pathlib import Path
 import json
@@ -17,7 +17,7 @@ def add_gcp_connection(known_args):
         os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = known_args.google_application_credentials
 
 
-def run(argv=None, save_main_session=True):
+def run(argv=None):
     parser = argparse.ArgumentParser()
 
     parser.add_argument('--input',
@@ -55,10 +55,8 @@ def run(argv=None, save_main_session=True):
 
     pipeline_options = PipelineOptions(pipeline_args)
 
-    pipeline_options.view_as(SetupOptions).save_main_session = save_main_session
-
     with beam.Pipeline(options=pipeline_options) as p:
-        lines = p | 'ReadFromGCS' >> ReadFromText(known_args.input)
+        lines = p | 'ReadFromText' >> ReadFromText(known_args.input)
 
         jsonsGroupedBySchema = (lines
                                 | 'JSONLoads' >> beam.Map(json.loads)
@@ -70,7 +68,7 @@ def run(argv=None, save_main_session=True):
             output_path = (Path(known_args.output) / schema["name"].replace(".", "_")).as_posix()
             (jsons
              | 'Map' >> beam.Map(lambda data: data["sdata"])
-             | 'WriteToGCS' >> WriteToAvro(output_path, schema=schema, file_name_suffix=".avro"))
+             | 'WriteToAvro' >> WriteToAvro(output_path, schema=schema, file_name_suffix=".avro"))
 
 if __name__ == '__main__':
     logging.getLogger().setLevel(logging.INFO)
